==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebToggleViewCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewCancelableEventArgsDetailDescriptionMetadata } from "./WebToggleViewCancelableEventArgsDetailDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDescription } from "./WebToggleViewCancelableEventArgsDescription";
/**
 * @hidden
 */
var WebToggleViewCancelableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebToggleViewCancelableEventArgsDescriptionMetadata, _super);
    function WebToggleViewCancelableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleViewCancelableEventArgsDescriptionMetadata.b = function (a) {
        if (WebToggleViewCancelableEventArgsDescriptionMetadata.a == null) {
            WebToggleViewCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleViewCancelableEventArgsDescriptionMetadata.c(WebToggleViewCancelableEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebToggleViewCancelableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebToggleViewCancelableEventArgsDescriptionMetadata.a);
        WebToggleViewCancelableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebToggleViewCancelableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ToggleViewCancelableEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebToggleViewCancelableEventArgsDetail");
    };
    WebToggleViewCancelableEventArgsDescriptionMetadata.d = function (a) {
        WebToggleViewCancelableEventArgsDescriptionMetadata.b(a);
        a.aa("WebToggleViewCancelableEventArgs", function () { return new WebToggleViewCancelableEventArgsDescription(); });
        a.z("WebToggleViewCancelableEventArgs", WebToggleViewCancelableEventArgsDescriptionMetadata.a);
    };
    WebToggleViewCancelableEventArgsDescriptionMetadata.$t = markType(WebToggleViewCancelableEventArgsDescriptionMetadata, 'WebToggleViewCancelableEventArgsDescriptionMetadata');
    WebToggleViewCancelableEventArgsDescriptionMetadata.a = null;
    return WebToggleViewCancelableEventArgsDescriptionMetadata;
}(Base));
export { WebToggleViewCancelableEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebToggleViewCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewCancelableEventArgsDetailDescriptionMetadata } from "./WebToggleViewCancelableEventArgsDetailDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDescription } from "./WebToggleViewCancelableEventArgsDescription";
/**
 * @hidden
 */
var WebToggleViewCancelableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebToggleViewCancelableEventArgsDescriptionMetadata, _super);
    function WebToggleViewCancelableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleViewCancelableEventArgsDescriptionMetadata.b = function (a) {
        if (WebToggleViewCancelableEventArgsDescriptionMetadata.a == null) {
            WebToggleViewCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleViewCancelableEventArgsDescriptionMetadata.c(WebToggleViewCancelableEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebToggleViewCancelableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebToggleViewCancelableEventArgsDescriptionMetadata.a);
        WebToggleViewCancelableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebToggleViewCancelableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ToggleViewCancelableEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebToggleViewCancelableEventArgsDetail");
    };
    WebToggleViewCancelableEventArgsDescriptionMetadata.d = function (a) {
        WebToggleViewCancelableEventArgsDescriptionMetadata.b(a);
        a.ac("WebToggleViewCancelableEventArgs", function () { return new WebToggleViewCancelableEventArgsDescription(); });
        a.ab("WebToggleViewCancelableEventArgs", WebToggleViewCancelableEventArgsDescriptionMetadata.a);
    };
    WebToggleViewCancelableEventArgsDescriptionMetadata.$t = markType(WebToggleViewCancelableEventArgsDescriptionMetadata, 'WebToggleViewCancelableEventArgsDescriptionMetadata');
    WebToggleViewCancelableEventArgsDescriptionMetadata.a = null;
    return WebToggleViewCancelableEventArgsDescriptionMetadata;
}(Base));
export { WebToggleViewCancelableEventArgsDescriptionMetadata };
